==> color-mate-10.0.1.tgz: share/emacs/site-lisp/color-mate/theme/SunnyDay-LCD.el <==
;;; SunnyDay-LCD.el Color-Mate standard definition for note PC -*-emacs-lisp-*-

;; Copyright (C) HIROSHI Yokota

;; Author: Hiroshi Yokota <yokota@netlab.is.tsukuba.ac.jp>
;; Maintainer: Hiroshi Yokota <yokota@netlab.is.tsukuba.ac.jp>
;; Version: 10.0
;; Keywords: color color-mate theme
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.10.0
;;         by  ͵ (yokota@netlab.is.tsukuba.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs/xemacs to more easier and more fun.
;;   mule / emacs / xemacs ǡѤƸ䤹̤ˤޤ
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file is part of Color-Mate

;; $Id: SunnyDay-LCD.el,v 10.1 1999/08/05 23:43:25 elca Exp $

(require 'assoc)

(setq color-mate:theme
      '(
	(frame-background-color .          "AntiqueWhite")
	;(frame-foreground-color .         "black")
	(frame-height . 30)
	;(frame-width . 80)
	(modeline-background-color . "green4")
	(modeline-foreground-color . "white")
	;(modeline-underlined . nil)
	(modeline-buffer-id-foreground-color . "cyan2")
	(modeline-mousable-foreground-color . "pink")
	(modeline-mousable-minor-mode-foreground-color . "palegreen")
	;(region-underlined . nil)
	(region-background-color . "gray80")
	(region-foreground-color . "navy")
	(cursor-background-color . "navy")
	(cursor-foreground-color . "white")
	(mouse-background-color . "white")
	(mouse-foreground-color . "red")
	;(menu-bar-lines . 1)
	;(font . "default-fontset")
	;(line-space . "1+1")
	))

;; for mule
(if (and (boundp 'MULE)
	 (eq window-system 'x))
    (aput 'color-mate:theme 'font "14"))

;; for Emacs20
(if (and (>= (string-to-int emacs-version) 20)
	 (not (string-match "XEmacs" emacs-version))
	 (eq window-system 'x))
    (aput 'color-mate:theme 'font "fontset-14"))

;; for XEmacs20
(if (and (>= (string-to-int emacs-version) 20)
	 (string-match "XEmacs" emacs-version))
    (aput 'color-mate:theme 'font
	  '("-misc-*-medium-r-normal-*-14-*-*-*-*-*-iso8859-1"
	    "-*-fixed-medium-r-*--14-*-jisx0201.1976-*"
	    "-*-fixed-medium-r-*--14-*-jisx0208.1983-*"
	    "-*-*-medium-r-*--14-*-jisx0212.1990-*")))

;; for "Mule for Windows"
;(if (eq window-system 'win32)
;      (aput 'color-mate:theme 'font "default"))


;; for Meadow
;(if (featurep 'meadow)
;      (aput 'color-mate:theme 'font "default-fontset"))

;;; SunnyDay-LCD.el ends here

==> color-mate-10.5.tgz: share/emacs/site-lisp/color-mate/theme/SunnyDay-LCD.el <==
;;; SunnyDay-LCD.el Color-Mate standard definition for note PC -*-emacs-lisp-*-

;; Copyright (C) YOKOTA Hiroshi

;; Author: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Maintainer: YOKOTA Hiroshi <yokota@netlab.is.tsukuba.ac.jp>
;; Version: 10.4
;; Keywords: color color-mate theme
;; Content-Type: text/plain; charset=x-euc-jp

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Color-Mate  Ver.10.4
;;         by  ͵ (yokota@netlab.is.tsukuba.ac.jp)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;   Coloring mule/emacs/xemacs to more easier and more fun.
;;   mule / emacs / xemacs ǡѤƸ䤹̤ˤޤ
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; This file is part of Color-Mate

;; $Id: SunnyDay-LCD.el,v 10.5 2001/03/15 14:26:34 elca Exp $

(setq color-mate:theme
      '(
	(frame-background-color .          "AntiqueWhite")
	;(frame-foreground-color .         "black")
	(frame-height . 30)
	;(frame-width . 80)
	(modeline-background-color . "green4")
	(modeline-foreground-color . "white")
	;(modeline-underlined . nil)
	(modeline-buffer-id-foreground-color . "cyan2")
	(modeline-mousable-foreground-color . "pink")
	(modeline-mousable-minor-mode-foreground-color . "palegreen")
	;(region-underlined . nil)
	(region-background-color . "gray80")
	(region-foreground-color . "navy")
	(cursor-background-color . "navy")
	(cursor-foreground-color . "white")
	(mouse-background-color . "white")
	(mouse-foreground-color . "red")
	;(menu-bar-lines . 1)
	(font . "fontset-14")
	;(line-space . "1+1")
	(face-type . light)
	))

;;; SunnyDay-LCD.el ends here
